@@ -57,24 +57,24 @@ def _turn_into_odoosh(ctx, path):
         content = yaml.safe_load((path / "gimera.yml").read_text())
     else:
         content = {"repos": []}
-    for subdir in ["odoo", "enterprise"]:
-        if (path / subdir).is_dir() and not (path / subdir).is_symlink():
-            shutil.rmtree(path / subdir)
+    # for subdir in ["odoo", "enterprise"]:
+    #     if (path / subdir).is_dir() and not (path / subdir).is_symlink():
+    #         shutil.rmtree(path / subdir)
 
-        pointto = odoosh_path / subdir / str(current_version())
-        pathsubdir = path / subdir
+    #     pointto = odoosh_path / subdir / str(current_version())
+    #     pathsubdir = path / subdir
 
-        if (
-            not pathsubdir.exists()
-            or (pathsubdir).exists()
-            and (pathsubdir).resolve().absolute() != pointto.resolve().absolute()
-        ):
-            if pathsubdir.exists() or pathsubdir.is_symlink():
-                pathsubdir.unlink()
-            ModulesCache.reset_cache()
-            pathsubdir.symlink_to(pointto.resolve().absolute())
-        content["repos"] = [x for x in content["repos"] if x["path"] != subdir]
-        __assure_gitignore(path / ".gitignore", str(subdir) + "/")
+    #     if (
+    #         not pathsubdir.exists()
+    #         or (pathsubdir).exists()
+    #         and (pathsubdir).resolve().absolute() != pointto.resolve().absolute()
+    #     ):
+    #         if pathsubdir.exists() or pathsubdir.is_symlink():
+    #             pathsubdir.unlink()
+    #         ModulesCache.reset_cache()
+    #         pathsubdir.symlink_to(pointto.resolve().absolute())
+    #     content["repos"] = [x for x in content["repos"] if x["path"] != subdir]
+    #     __assure_gitignore(path / ".gitignore", str(subdir) + "/")
 
     (path / "gimera.yml").write_text(yaml.dump(content, default_flow_style=False))
     click.secho("Please reload now!", fg="yellow")
